#!/usr/bin/env python
import pytest
import logging
import os

from p2.driver.k8s import k8s

log = logging.getLogger(__name__)


@pytest.fixture
def config():

    api_obj = k8s.Api(context='minikube')


def test_api_no_context():
    api = k8s.Api()
    ns = api.namespaces()
    assert len(ns) > 0

def test_nodes_as_dict():
    api = k8s.Api()
    nodes = api.nodes_as_dict()
    assert len(nodes) > 0


def test_namespaces_as_dict(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces_as_dict()
    assert len(ns) > 0
    assert ns[0]['metadata']['name'] == 'default'


def test_namespaces(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0


def test_namespaces_with_pattern(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces(pattern="(\w+)-public")
    assert len(ns) == 1
    assert ns[0]['name'] == 'kube-public'


def test_namespaces_with_skip(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces(skip=['kube'])
    assert len(ns) == 1
    assert ns[0]['name'] == 'default'


def test_deployments_for_namespace_as_dict(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0
    for namespace in ns:
        name = namespace['name']
        print("Getting deployments for namespace " + name)
        d = api.deployments_for_namespace_as_dict(name)
        assert type(d) is list


def test_deployments_for_namespace(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0
    for namespace in ns:
        name = namespace['name']
        print("Getting deployments for namespace " + name)
        d = api.deployments_for_namespace(name)
        assert type(d) is dict


def test_is_deployment_healthy(config):
    api = k8s.Api(context='minikube')
    deployment={"DESIRED_REPLICAS": 2, "name": "k8-account-data-checker", "namespace": "acdc-int-nft", "labels": {"app": "k8-account-data-checker", "deployment": "k8-account-data-checker", "team": "njp"}, "status": {"available_replicas": 2, "ready_replicas": 2, "replicas": 2, "updated_replicas": 2}}
    assert api.is_deployment_healthy(deployment) is True


def test_pods_in_namespace(config):
    api = k8s.Api(context='minikube')
    ns = api.namespaces()
    assert len(ns) > 0
    name = ns[0]["name"]
    pods = api.pods_in_namespace(name)
    assert len(pods) >= 0


def test_access_review_pods(config):
    api = k8s.Api(context='minikube')
    access = api.access_review(
            namespace='default',
            verb='delete',
            resource='pods'
            )
    assert access == True


def test_access_review_deployments(config):
    api = k8s.Api(context='minikube')
    access = api.access_review(
            namespace='default',
            group='extensions',
            verb='update',
            resource='deployments/scale'
            )
    assert access == True
